@@ -14,15 +14,69 @@
  Original:	March 1990
 
 
- $Revision: 8.30 $
- $Date: 2001/11/12 10:00:00 $
+ $Revision: 8.48 $
+ $Date: 2002/09/04 12:55:53 $
 
  $Author: goetz $
 
- $Log:	DevServer.h,v $
- * Revision 8.30  2001/11/12  10:00:00  10:00:00  goetz (Andy Goetz)
- * updated C port for Windows 95/98/NT using Visual C++ 6
+ $Log: DevServer.h,v $
+ Revision 8.48  2002/09/04 12:55:53  goetz
+ changed char* to string for tango api in tango_api.cpp
+
+ Revision 8.47  2002/06/27 11:57:01  goetz
+ fixed bug in stateless import with database
+
+ Revision 8.46  2002/06/25 07:26:29  goetz
+ extended stateless import to host down and all rpc errors
+
+ Revision 8.45  2002/06/18 07:44:03  goetz
+ NFILE reduced to 100 for OS9
+
+ Revision 8.44  2002/06/11 17:32:47  goetz
+ fixed double declaration of i in tango_api.cpp
+
+ Revision 8.43  2002/06/10 12:09:39  goetz
+ added Tango::INIT state to tango_api.cpp
+
+ Revision 8.42  2002/05/30 15:11:45  goetz
+ ported to C++ on Windows
+
+ Revision 8.41  2002/04/14 13:10:37  goetz
+ ported -nodb option to Windows
+
+ * Revision 8.40  2002/03/18  10:11:01  10:11:01  goetz (Andy Goetz)
+ * removed ^M from files which were confusing Ultra C++ compiler
  * 
+ * Revision 8.39  2002/03/18  05:48:53  05:48:53  goetz (Andy Goetz)
+ * added tango_dev_free() and dev_error_clear(); error message in command_handler
+ * 
+ Revision 8.38  2002/03/13 07:29:25  goetz
+ fixed bug initializing struct _devserver to zero; rpc_protocol=D_UDP
+
+ Revision 8.37  2002/03/11 14:20:21  goetz
+ initalise prog_number and config_flags to zero at startup
+
+ Revision 8.36  2002/03/07 15:58:46  goetz
+ fixed leak in extract_device_name
+
+ Revision 8.35  2002/03/06 22:08:44  goetz
+ made stateless import and reimport work for no database devices
+
+ Revision 8.34  2002/03/06 21:00:08  goetz
+ added -nodb option to device_server(); suppressed -m -s; improved dev_cmd_query
+
+ Revision 8.33  2002/03/05 11:52:49  goetz
+ added command name to C++ commands_list, asynchronous and events support -nodb
+
+ Revision 8.32  2002/03/03 22:45:09  goetz
+ added TACO-lite option i.e. no database
+
+ Revision 8.31  2002/02/28 12:13:07  goetz
+ setup_config() and setup_config_multi() now call rpc_nt_init() for Windows
+
+ Revision 8.30  2001/11/12 10:00:00  goetz
+ updated C port for Windows 95/98/NT using Visual C++ 6
+
  * Revision 8.20  2001/01/08  13:14:55  13:14:55  goetz (Andy Goetz)
  * added patch by B.Pedersen to support querying events
  * 
@@ -232,7 +286,7 @@
  */
 #ifdef _IDENT
 static char DevServerh[] =
-"@(#)$Header: DevServer.h,v 8.30 2001/11/12 10:00:00 goetz Rel $";
+"@(#)$Header: /segfs/dserver/classes/main/include/RCS/DevServer.h,v 8.48 2002/09/04 12:55:53 goetz Rel $";
 #endif /* _IDENT */
 
 
