@@ -12,7 +12,31 @@
 
  Original:	March 1990
 
- $Log:	DevServerP.h,v $
+ $Log: DevServerP.h,v $
+ Revision 8.48  2002/09/04 12:55:53  goetz
+ changed char* to string for tango api in tango_api.cpp
+
+ Revision 8.47  2002/06/27 11:57:01  goetz
+ fixed bug in stateless import with database
+
+ Revision 8.46  2002/06/25 07:26:29  goetz
+ extended stateless import to host down and all rpc errors
+
+ Revision 8.45  2002/06/18 07:44:03  goetz
+ NFILE reduced to 100 for OS9
+
+ Revision 8.44  2002/06/11 17:32:46  goetz
+ fixed double declaration of i in tango_api.cpp
+
+ Revision 8.43  2002/06/10 12:09:39  goetz
+ added Tango::INIT state to tango_api.cpp
+
+ Revision 8.42  2002/05/30 15:11:45  goetz
+ ported to C++ on Windows
+
+ Revision 8.41  2002/04/14 13:10:37  goetz
+ ported -nodb option to Windows
+
  * Revision 8.40  2002/03/18  10:11:00  10:11:00  goetz (Andy Goetz)
  * removed ^M from files which were confusing Ultra C++ compiler
  * 
@@ -282,7 +306,7 @@
  */
 #ifdef _IDENT
 static char DevServerPh[] =
-"@(#)$Header: DevServerP.h,v 8.40 2002/03/18 10:11:00 goetz Rel $";
+"@(#)$Header: /segfs/dserver/classes/main/include/RCS/DevServerP.h,v 8.48 2002/09/04 12:55:53 goetz Rel $";
 #endif /* _IDENT */
 
 /*
