@@ -1,5 +1,5 @@
 static char RcsId[]      =
-"@(#)$Header: svc_api.c,v 8.30 2001/11/12 09:59:59 goetz Rel $";
+"@(#)$Header: /segfs/dserver/classes/main/src/RCS/svc_api.c,v 8.48 2002/09/04 12:55:53 goetz Rel $";
 /*+*******************************************************************
 
  File:		svc_api.c
@@ -12,15 +12,69 @@ static char RcsId[]      =
 
  Original:	Feb 1994
 
- $Revision: 8.30 $
- $Date: 2001/11/12 09:59:59 $
+ $Revision: 8.48 $
+ $Date: 2002/09/04 12:55:53 $
 
  $Author: goetz $
 
- $Log:	svc_api.c,v $
- * Revision 8.30  2001/11/12  09:59:59  09:59:59  goetz (Andy Goetz)
- * updated C port for Windows 95/98/NT using Visual C++ 6
+ $Log: svc_api.c,v $
+ Revision 8.48  2002/09/04 12:55:53  goetz
+ changed char* to string for tango api in tango_api.cpp
+
+ Revision 8.47  2002/06/27 11:57:00  goetz
+ fixed bug in stateless import with database
+
+ Revision 8.46  2002/06/25 07:26:29  goetz
+ extended stateless import to host down and all rpc errors
+
+ Revision 8.45  2002/06/18 07:44:02  goetz
+ NFILE reduced to 100 for OS9
+
+ Revision 8.44  2002/06/11 17:32:37  goetz
+ fixed double declaration of i in tango_api.cpp
+
+ Revision 8.43  2002/06/10 12:09:38  goetz
+ added Tango::INIT state to tango_api.cpp
+
+ Revision 8.42  2002/05/30 15:11:43  goetz
+ ported to C++ on Windows
+
+ Revision 8.41  2002/04/14 13:07:01  goetz
+ ported -nodb option to Windows
+
+ * Revision 8.40  2002/03/18  10:10:51  10:10:51  goetz (Andy Goetz)
+ * removed ^M from files which were confusing Ultra C++ compiler
  * 
+ * Revision 8.39  2002/03/18  05:48:51  05:48:51  goetz (Andy Goetz)
+ * added tango_dev_free() and dev_error_clear(); error message in command_handler
+ * 
+ Revision 8.38  2002/03/13 07:29:25  goetz
+ fixed bug initializing struct _devserver to zero; rpc_protocol=D_UDP
+
+ Revision 8.37  2002/03/11 14:20:20  goetz
+ initalise prog_number and config_flags to zero at startup
+
+ Revision 8.36  2002/03/07 15:58:45  goetz
+ fixed leak in extract_device_name
+
+ Revision 8.35  2002/03/06 22:08:43  goetz
+ made stateless import and reimport work for no database devices
+
+ Revision 8.34  2002/03/06 21:00:08  goetz
+ added -nodb option to device_server(); suppressed -m -s; improved dev_cmd_query
+
+ Revision 8.33  2002/03/05 11:52:48  goetz
+ added command name to C++ commands_list, asynchronous and events support -nodb
+
+ Revision 8.32  2002/03/03 22:44:59  goetz
+ added TACO-lite option i.e. no database
+
+ Revision 8.31  2002/02/28 12:13:06  goetz
+ setup_config() and setup_config_multi() now call rpc_nt_init() for Windows
+
+ Revision 8.30  2001/11/12 09:59:59  goetz
+ updated C port for Windows 95/98/NT using Visual C++ 6
+
  Revision 8.29  2001/07/26 05:05:09  goetz
  fixed error in CORBA::is_nil() test
 
@@ -154,7 +208,11 @@ static char RcsId[]      =
  *  Configuration flags
  */
 
+#ifdef __cplusplus
+extern "C" configuration_flags      config_flags;
+#else
 extern configuration_flags      config_flags;
+#endif
 
 /*
  *  Debug flag
@@ -790,7 +848,7 @@ _client_raw_data * _DLLFunc rpc_dev_putget_raw_4 (_server_data *server_data)
  *  allocate and initialise outgoing arguments 
  */
 
-	free (client_data.argout);
+	if (client_data.argout != NULL) free (client_data.argout);
 	memset ((char *)&client_data,0,sizeof(client_data));
 
 	/*
@@ -1310,6 +1368,12 @@ free_found:;
 
    TOLOWER(name)
 
+/* 
+ * do not export the device to the static database if
+ * no_database is selected ...
+ */
+   if (!config_flags.no_database)
+   {
    /*
     *  export device to the static database.
     *  device server configuration for this device
@@ -1317,31 +1381,31 @@ free_found:;
     */
 
 
-   devinfo.device_name = name;
-   strcpy(server_host,config_flags.server_host);
-   devinfo.host_name   = server_host;
-   devinfo.pn	       = (u_int)config_flags.prog_number;
-   devinfo.vn          = (u_int)config_flags.vers_number;
+      devinfo.device_name = name;
+      strcpy(server_host,config_flags.server_host);
+      devinfo.host_name   = server_host;
+      devinfo.pn	       = (u_int)config_flags.prog_number;
+      devinfo.vn          = (u_int)config_flags.vers_number;
 
    /*
     * Extract the name of the executable
     */
-   sprintf (proc_name,"%s", config_flags.server_name);
-   strptr = strchr (proc_name, '/');
-   *strptr = '\0'; 
-   devinfo.proc_name   = proc_name;
+      sprintf (proc_name,"%s", config_flags.server_name);
+      strptr = strchr (proc_name, '/');
+      *strptr = '\0'; 
+      devinfo.proc_name   = proc_name;
 
 #ifndef __cplusplus
 /*
  * OIC version
  */
-   devinfo.device_class = 
+      devinfo.device_class = 
 	(ds->devserver.class_pointer)->devserver_class.class_name;
 #else
 /*
  * C++ version
  */
-   devinfo.device_class = device->class_name;
+      devinfo.device_class = device->class_name;
 #endif /* __cplusplus */
 
    /*
@@ -1353,32 +1417,33 @@ free_found:;
 /*
  * OIC version
  */
-   if ( strncmp (ds->devserver.dev_type, TYPE_INIT, strlen(TYPE_INIT)) != 0 )
+      if ( strncmp (ds->devserver.dev_type, TYPE_INIT, strlen(TYPE_INIT)) != 0 )
 	 {
          sprintf (ds->devserver.dev_type, TYPE_DEFAULT );
 	 }
-   devinfo.device_type  = ds->devserver.dev_type;
+      devinfo.device_type  = ds->devserver.dev_type;
 #else
 /*
  * C++ version
  */
-   devinfo.device_type  = device->dev_type;
+      devinfo.device_type  = device->dev_type;
 #endif /* __cplusplus */
 
 
 
 #ifdef EBUG
-   dev_printdebug (DBG_DEV_SVR_CLASS,
+      dev_printdebug (DBG_DEV_SVR_CLASS,
    	   "dev_export() :  name = %s , class = %s , type = %s\n",
 	    devinfo.device_name, devinfo.device_class, devinfo.device_type);
-   dev_printdebug (DBG_DEV_SVR_CLASS,
+      dev_printdebug (DBG_DEV_SVR_CLASS,
    	   "dev_export() :  host_name = %s , proc = %s , pn = %d , vn = %d\n",
       	    devinfo.host_name, devinfo.proc_name, devinfo.pn, devinfo.vn );
 #endif /* EBUG */
 
 
-   if ( db_dev_export (&devinfo,1,error) < 0 )
+      if ( db_dev_export (&devinfo,1,error) < 0 )
 	return (-1);
+   }
 
 
 /*
@@ -1565,6 +1630,7 @@ _dev_query_out * _DLLFunc rpc_dev_cmd_query_4 (_dev_query_in *dev_query_in)
 static _dev_query_out	dev_query_out = { 0, NULL, "", 0, 0, { 0, NULL}};
 long        ds_id;
 long        connection_id;
+static DevVarArgument vararg[1024];
 #ifndef __cplusplus
 /*
  * OIC version
@@ -1580,6 +1646,7 @@ _Int			i;
 Device			*device;
 long 			error;
 long 			ret;
+int			i;
 #endif
 
 #ifdef EBUG
@@ -1689,6 +1756,41 @@ if (ret != DS_OK)
 sprintf (dev_query_out.class_name, "%s", device->class_name);
 #endif /* __cplusplus */
 
+/* 
+ * if the device server command list has specified the command names
+ * (by testing the first entry != NULL)
+ * then tag them onto the end of the sequence so that the client
+ * does not have to query the database for them (very useful if -nodb)
+ *
+ * andy 3/3/2002
+ */
+
+#ifndef __cplusplus
+if (ds_cl[0].cmd_name != NULL)
+{
+        dev_query_out.var_argument.length = 0;
+	for (i=0; (u_long)i<dev_query_out.length; i++)
+	{
+        	vararg[i].argument_type      = D_STRING_TYPE;
+        	vararg[i].argument           = (DevArgument)&ds_cl[i].cmd_name;
+	}
+        dev_query_out.var_argument.length = dev_query_out.length;
+        dev_query_out.var_argument.sequence = vararg;
+}
+#else
+if (device->commands_list[0].cmd_name != NULL)
+{
+	dev_query_out.var_argument.length = 0;
+	for (i=0; (u_long)i<dev_query_out.length; i++)
+	{
+		vararg[i].argument_type      = D_STRING_TYPE;
+		vararg[i].argument           = (DevArgument)&(device->commands_list[i].cmd_name);
+	}
+        dev_query_out.var_argument.length = dev_query_out.length;
+        dev_query_out.var_argument.sequence = vararg;
+}
+#endif /* __cplusplus */
+
 return (&dev_query_out);
 }
 
