@@ -12,10 +12,16 @@
  Original      :  June 1998
 
 
- $Revision: 3.12 $
- $Date: 99/02/23 15:19:12 $
+ $Revision: 3.14 $
+ $Date: 2002/09/05 09:34:07 $
 
  $Log:	devutil.c,v $
+ * Revision 3.14  2002/09/05  09:34:07  09:34:07  taurel (E.Taurel)
+ * Print device info even for non-exported device
+ * 
+ * Revision 3.13  00/04/03  13:03:19  13:03:19  taurel (E.Taurel)
+ * change buffer size when the hdbget_info function is called (4000 instead of 2000)
+ * 
  * Revision 3.12  99/02/23  15:19:12  15:19:12  taurel (Emmanuel Taurel)
  * Fix bug in xsCreateStringForTextServ function. Same bug than in release 3.5 !
  * 
@@ -126,7 +132,29 @@ void devinfo_str(db_devinfo_call *p_info,char *dev_name,char *info_str)
 	if (p_info->device_type == DB_Device)
 	{	
 		if (p_info->device_exported == False)
-			sprintf(info_str,"The device %s is not actually exported",dev_name);
+		{
+			sprintf(info_str,"The device %s is not actually exported\n\n",dev_name);
+			if (strcmp(p_info->device_class,"unknown") != 0)
+			{
+				sprintf(tmp,"Device %s belongs to class %s\n",dev_name,p_info->device_class);
+				strcat(info_str,tmp);
+			}
+			if (strcmp(p_info->server_name,"unknown") != 0)
+			{
+				sprintf(tmp,"It is monitored by the server : %s/%s\n",p_info->server_name,p_info->personal_name);
+				strcat(info_str,tmp);
+			}
+			if (strcmp(p_info->process_name,"unknown") != 0)
+			{
+				sprintf(tmp,"The device server process name is : %s\n",p_info->process_name);
+				strcat(info_str,tmp);
+			}
+			if (strcmp(p_info->host_name,"not_exp") != 0)
+			{
+				sprintf(tmp,"Last host on which the process was running : %s\n",p_info->host_name);
+				strcat(info_str,tmp);
+			}
+		}
 		else
 		{
 			sprintf(info_str,"Device %s belongs to class : %s\n",dev_name,p_info->device_class);
