@@ -1,6 +1,9 @@
+/*
 #include <string.h>
 #include <ndbm.h>
 #include <stdlib.h>
+ */
+#include <cstdlib>
 
 #include <macros.h>
 #include <db_setup.h>
@@ -12,8 +15,8 @@
 #include <string>
 #include <algorithm>
 #include <string>
-#include <iostream.h>
-#include <strstream.h>
+#include <iostream>
+#include <strstream>
 
 
 //****************************************************************************
