@@ -82,7 +82,7 @@ Added
 
 #include <string>
 #include <NdbmClass.h>
-#include <iostream.h>
+#include <iostream>
 
 /* Variables defined elsewhere */
 
