@@ -112,7 +112,7 @@ Added
 
 /* Some C++ include files */
 
-#include <iostream.h>
+#include <iostream>
 #include <NdbmClass.h>
 
 /* Some local function definition */
