@@ -1,6 +1,9 @@
-static char RcsId[] = "$Header: /segfs/dbase/res/svc/ndbm/RCS/dbm_resbro.cpp,v 6.9 2000/03/15 17:07:47 taurel Rel goetz $";
+static char RcsId[] = "$Header: dbm_resbro.cpp,v 6.10 2001/01/08 11:45:53 goetz Rel $";
+
+/* $Log:	dbm_resbro.cpp,v $
+Revision 6.10  2001/01/08  11:45:53  11:45:53  goetz (Andy Goetz)
+added patch by B.Pedersen to support querying events
 
-/* $Log: dbm_resbro.cpp,v $
  * Revision 6.9  2000/03/15 17:07:47  taurel
  * Change compilation variable from -solaris to sun
  *
@@ -43,7 +46,7 @@ Added
 
 #include <new>
 #include <string>
-#include <iostream.h>
+#include <iostream>
 #include <NdbmClass.h>
 
 /* Some local functions declaration */
