@@ -45,7 +45,7 @@ Added
 // C++ include
 
 #include <new>
-#include <iostream.h>
+#include <iostream>
 #include <NdbmClass.h>
 #include <string>
 #include <vector>
