@@ -1,6 +1,9 @@
-static char RcsId[] = "$Header: /segfs/dbase/res/svc/ndbm/RCS/dbm_update.cpp,v 6.9 2000/03/15 17:07:57 taurel Rel goetz $";
+static char RcsId[] = "$Header: dbm_update.cpp,v 6.10 2001/01/08 11:45:53 goetz Rel $";
+
+/* $Log:	dbm_update.cpp,v $
+Revision 6.10  2001/01/08  11:45:53  11:45:53  goetz (Andy Goetz)
+added patch by B.Pedersen to support querying events
 
-/* $Log: dbm_update.cpp,v $
  * Revision 6.9  2000/03/15 17:07:57  taurel
  * Change compilation variable from -solaris to sun
  *
@@ -41,9 +44,9 @@ Added
 
 // Some C++ include
 
-#include <iostream.h>
+#include <iostream>
 #include <NdbmClass.h>
-#include <fstream.h>
+#include <fstream>
 
 /* Some local functions declaration */
 
