@@ -60,8 +60,8 @@ Added
 
 // C++ include
 
-#include <iostream.h>
-#include <fstream.h>
+#include <iostream>
+#include <fstream>
 #include <NdbmClass.h>
 #include <string>
 #include <vector>
