@@ -1,4 +1,4 @@
-static char RcsId[] = "@(#)$Header: /segfs/dbase/res/clnt/RCS/browse_cli.c,v 6.14 2001/09/12 14:53:02 taurel Rel $";
+static char RcsId[] = "@(#)$Header: /segfs/dbase/res/clnt/RCS/browse_cli.c,v 6.16 2002/04/09 13:47:24 goetz Rel $";
 
 /*+*******************************************************************
 
@@ -17,6 +17,12 @@ static char RcsId[] = "@(#)$Header: /segfs/dbase/res/clnt/RCS/browse_cli.c,v 6.1
 
 
  * $Log: browse_cli.c,v $
+ * Revision 6.16  2002/04/09 13:47:24  goetz
+ * ported to Windows
+ *
+ * Revision 6.15  2002/03/07  15:47:51  15:47:51  goetz (Andy Goetz)
+ * added no database to db_getdevlist(), error DbErr_NoDatabase to others
+ * 
  * Revision 6.14  2001/09/12 14:53:02  taurel
  * Add db_exp.cpp file with function to get Tango device name in db_getdevexp call (C++ only)
  *
@@ -75,7 +81,7 @@ static char RcsId[] = "@(#)$Header: /segfs/dbase/res/clnt/RCS/browse_cli.c,v 6.1
 #include <API.h>
 #include <ApiP.h>
 #include <DevErrors.h>
-#include <nm_rpc.h>
+#include <rpc.h>
 
 #else
 #include <API.h>
