@@ -1,5 +1,5 @@
 static char RcsId[]         = 
-"@(#)$Header: DevServerMain.c,v 8.30 2001/11/12 09:59:59 goetz Rel $";
+"@(#)$Header: /segfs/dserver/classes/main/src/RCS/DevServerMain.c,v 8.48 2002/09/04 12:55:53 goetz Rel $";
 
 /*+*******************************************************************
 
@@ -14,14 +14,68 @@ static char RcsId[]         =
  Original   :	March 1991
 
 
- $Revision: 8.30 $
- $Date: 2001/11/12 09:59:59 $
+ $Revision: 8.48 $
+ $Date: 2002/09/04 12:55:53 $
  $Author: goetz $
 
- $Log:	DevServerMain.c,v $
- * Revision 8.30  2001/11/12  09:59:59  09:59:59  goetz (Andy Goetz)
- * updated C port for Windows 95/98/NT using Visual C++ 6
+ $Log: DevServerMain.c,v $
+ Revision 8.48  2002/09/04 12:55:53  goetz
+ changed char* to string for tango api in tango_api.cpp
+
+ Revision 8.47  2002/06/27 11:57:00  goetz
+ fixed bug in stateless import with database
+
+ Revision 8.46  2002/06/25 07:26:29  goetz
+ extended stateless import to host down and all rpc errors
+
+ Revision 8.45  2002/06/18 07:44:02  goetz
+ NFILE reduced to 100 for OS9
+
+ Revision 8.44  2002/06/11 17:32:42  goetz
+ fixed double declaration of i in tango_api.cpp
+
+ Revision 8.43  2002/06/10 12:09:38  goetz
+ added Tango::INIT state to tango_api.cpp
+
+ Revision 8.42  2002/05/30 15:11:43  goetz
+ ported to C++ on Windows
+
+ Revision 8.41  2002/04/14 13:07:01  goetz
+ ported -nodb option to Windows
+
+ * Revision 8.40  2002/03/18  10:10:56  10:10:56  goetz (Andy Goetz)
+ * removed ^M from files which were confusing Ultra C++ compiler
  * 
+ * Revision 8.39  2002/03/18  05:48:51  05:48:51  goetz (Andy Goetz)
+ * added tango_dev_free() and dev_error_clear(); error message in command_handler
+ * 
+ Revision 8.38  2002/03/13 07:29:25  goetz
+ fixed bug initializing struct _devserver to zero; rpc_protocol=D_UDP
+
+ Revision 8.37  2002/03/11 14:20:20  goetz
+ initalise prog_number and config_flags to zero at startup
+
+ Revision 8.36  2002/03/07 15:58:45  goetz
+ fixed leak in extract_device_name
+
+ Revision 8.35  2002/03/06 22:08:43  goetz
+ made stateless import and reimport work for no database devices
+
+ Revision 8.34  2002/03/06 21:00:08  goetz
+ added -nodb option to device_server(); suppressed -m -s; improved dev_cmd_query
+
+ Revision 8.33  2002/03/05 11:52:48  goetz
+ added command name to C++ commands_list, asynchronous and events support -nodb
+
+ Revision 8.32  2002/03/03 22:45:04  goetz
+ added TACO-lite option i.e. no database
+
+ Revision 8.31  2002/02/28 12:13:06  goetz
+ setup_config() and setup_config_multi() now call rpc_nt_init() for Windows
+
+ Revision 8.30  2001/11/12 09:59:59  goetz
+ updated C port for Windows 95/98/NT using Visual C++ 6
+
  Revision 8.29  2001/07/26 05:05:09  goetz
  fixed error in CORBA::is_nil() test
 
@@ -118,137 +172,7 @@ static char RcsId[]         =
  Revision 8.0  1999/12/28 14:18:31  goetz
  added TANGO support for TACO dev_xxx() calls via -DTANGO for C++
 
- Revision 7.10  1999/11/25 08:27:13  goetz
- replaced fprintf(stderr) with printf; made startup() C++ compatible
-
- Revision 7.9  1999/11/22 20:18:59  goetz
- removed const from gettransient() prototype
-
- Revision 7.8  1999/11/21 20:45:37  goetz
- included all M.Diehl's patches (major changes to gettransient() + main())
-
- Revision 7.7  1999/11/18 22:29:01  goetz
- fixed event multi-client bug, free client handle after event_listen, timeout in dev_synch()
-
- Revision 7.6  1999/11/01 19:05:16  goetz
- make local copy of user name returned by getpwuid() in sec_api.c
-
- Revision 7.5  1999/08/06 17:44:14  goetz
- removed usage of varargs for g++ on solaris and hpux
-
- * Revision 7.4  99/07/09  05:15:27  05:15:27  goetz (Andy Goetz)
- * added M.Diehl's patch to DevServerSig.c to exit() after calling unregister_server()
- * 
- Revision 7.3  1999/06/07 15:27:02  goetz
- fixed bug with multi-nethost reimport, device name stored with nethost
-
- Revision 7.2  1999/05/12 15:22:04  goetz
- changed dev_event_fire() to void; fixed bug in dev_event_unlisten()
-
- * Revision 7.1  99/05/11  15:59:51  15:59:51  goetz (Andy Goetz)
- * replace static declaration of event_client[] array by malloc()
- * 
- Revision 7.0  1999/04/26 07:30:44  goetz
- implemented user events (added event_api.c)
-
- Revision 6.15  1999/03/27 09:00:22  goetz
- asynch_cleanup() only checks for asynch clients; C++ returns output arguments if DS_WARNING
-
- * Revision 6.14  99/02/27  15:21:22  15:21:22  goetz (Andy Goetz)
- * fixed reimport bug; disabled reimport for rpc version 1
- * 
- Revision 6.13  1999/02/05 00:50:29  goetz
- fixed reimport socket+memory leak; ported to aCC on HPUX; suppressed rpc errors
-
- * Revision 6.12  99/01/18  21:39:06  21:39:06  goetz (Andy Goetz)
- * suppressed test for RPC_TIMEDOUT in svc_check()
- * 
- * Revision 6.11  99/01/14  23:14:55  23:14:55  goetz (Andy Goetz)
- * dbase timeout = 4 s; unregister ver. 1; svc_check() handles RPC_TIMEDOUT
- * 
- * Revision 6.10  98/12/22  10:29:48  10:29:48  taurel (E.Taurel)
- * Added support for Solaris and HP C++ native compiler. Remove K_R C support
- * 
- * Revision 6.9  98/12/15  14:05:09  14:05:09  goetz (Andy Goetz)
- * unregister RPC; use pgm no. 1 as flag; dev_pending() checks timeout; extern C prototype
- * 
- * Revision 6.8  98/11/20  14:35:38  14:35:38  goetz (Andy Goetz)
- * unregister API_VERSION (4) correctly now + check return value of svc_register()
- * 
- * Revision 6.7  98/11/20  10:35:03  10:35:03  goetz (Andy Goetz)
- * improved gettrans_ut(); multi-config_flags=0; removde static client_data; fixed linux select() bug; only register pgm # 0,4,5; portmap address == 111
- * 
- * Revision 6.6  98/09/24  09:25:11  09:25:11  goetz (Andy Goetz)
- * fixed stupid type which reintroduced asynchronous memory leak
- * 
- * Revision 6.5  98/08/26  16:20:36  16:20:36  goetz (Andy Goetz)
- * added dynamic NETHOST allocation, fixed bug in db_setup_multi, ported to Irix 6.4
- * 
- * Revision 6.4  98/04/29  10:21:24  10:21:24  goetz (Andy Goetz)
- * asynchronous - memory leak fixed, OS9 bug fixed, stale handle cleanup, pending=300
- * 
- * Revision 6.3  97/12/10  15:28:35  15:28:35  meyer (J.Meyer)
- * Changed select() timeout in rpc_check_host() to 200ms
- * 
- * Revision 6.2  97/12/01  12:59:17  12:59:17  goetz (Andy Goetz)
- * intermediate checkin before opening 5.14.1 branch
- * 
- * Revision 6.1  97/11/20  21:49:27  21:49:27  goetz (Andy Goetz)
- * main() continue even if cannot register asynch rpc
- * 
- * Revision 6.0  97/11/03  17:22:28  17:22:28  goetz (Andy Goetz)
- * merged synchronous and asynchronous branches
- * 
- Revision 5.15  1997/10/24 15:27:02  klotz
- ported to Windows NT 4.0 + NMSDK 5.0 ; tested with TextTalkds ; new DevServerMain.c
-
- * Revision 5.14  97/09/25  17:36:42  17:36:42  goetz (Andy Goetz)
- * fixed
- * 
- Revision 5.13  1997/09/03 17:34:35  meyer
- Added casting for ucc++ in DevServerSig.c
-
- * Revision 5.12  97/09/03  15:54:11  15:54:11  meyer (J.Meyer)
- * Changed OS9 signal handling from intercept() to signal().
- * 
- * Revision 5.11  97/08/05  14:19:28  14:19:28  goetz (Andy Goetz)
- * ported to VxWork 5.2, pgm. no. based on CRC, -m suppressed, -ve errors bug fix
- * 
- * Revision 5.10  97/03/14  17:26:11  17:26:11  dserver ()
- * fixed bug with open file handles after free
- * 
- * Revision 5.8.1.4  97/03/14  17:24:50  17:24:50  goetz (Andy Goetz)
- * fixed bug with open file handles after free
- * 
- * Revision 5.9  97/03/13  11:17:14  11:17:14  klotz (W.D. Klotz)
- * first part of NT4.0 port
- * 
- * Revision 5.8  97/01/31  12:06:23  12:06:23  goetz (Andy Goetz)
- * dev_protocol(), Linux+security bug fixes, dev_import() ignores timeout on NULL procedure, svc_run for OS9
- * 
- * Revision 5.7  97/01/14  08:57:19  08:57:19  goetz (Andy Goetz)
- * added stateless to dev_free(),_raw(),_asyn(),_protocol(),_timeout()
- * 
- * Revision 5.6  97/01/12  18:33:39  18:33:39  goetz (Andy Goetz)
- * dev_import() now stateless i.e. import works even if server is not running
- * 
- * Revision 5.5  97/01/08  17:02:28  17:02:28  goetz (Andy Goetz)
- * Ported to Linux (2.0.9)
- * 
- * Revision 5.4  96/11/27  09:58:14  09:58:14  goetz (Andy Goetz)
- * removed rpc admin interface from DevServerMain.c; putenv() suppressed for _UCC
- * 
- * Revision 5.3  96/11/26  16:24:40  16:24:40  goetz (Andy Goetz)
- * fixed bug (i_nethost=0) in dev_import_local()
- * 
- * Revision 5.2  96/11/26  13:31:03  13:31:03  goetz (Andy Goetz)
- * OICDevice (C++ wrapper for OIC) added + fixed multi-nethost memory leaks
- * 
- * Revision 5.1  96/11/04  11:00:06  11:00:06  goetz (Andy Goetz)
- * added multi nethost support
- * 
-
- Copyright (c) 1990-1997 by  European Synchrotron Radiation Facility,
+ Copyright (c) 1990-2002 by  European Synchrotron Radiation Facility,
 			     Grenoble, France
 
 *******************************************************************-*/
@@ -334,8 +258,8 @@ extern configuration_flags      config_flags;
 static int	udp_socket;
 static int	tcp_socket;
 
-long synch_svc_udp_sock;
-long synch_svc_tcp_sock;
+extern long synch_svc_udp_sock;
+extern long synch_svc_tcp_sock;
 
 /*
  * debug flag
@@ -350,13 +274,7 @@ static SVCXPRT *transp_tcp;
  */
 
 #if defined (vxworks) || (NOMAIN)
-#ifdef __cplusplus
-void device_server (char *server_name, char *pers_name)
-#else /* __cplusplus */
-void device_server (server_name, pers_name)
-char *server_name; 
-char *pers_name;
-#endif /* __cplusplus */
+void device_server (char *server_name, char *pers_name, int nodb, int pn, int n_device, char** device_list)
 {
 
         char    host_name [19];
@@ -369,12 +287,13 @@ char *pers_name;
         DevVarStringArray       default_access;
         db_resource             res_tab;
 
-        long    prog_number;
+        long    prog_number=0;
         long    status;
         long    error = 0;
         int     pid = 0;
         short   m_opt = False;
         short   s_opt = True;
+        short   nodb_opt = False;
         short   sig;
         short   i;
 
@@ -402,6 +321,34 @@ char *pers_name;
 	strncat (dsn_name , proc_name, 23);
 	strncat (dsn_name , "/", 1);
 	strncat (dsn_name , pers_name, 11);
+/*
+ * option nodb means run device server without database
+ */
+	if (nodb > 0)
+	{
+                 nodb_opt = True;
+                 config_flags.no_database = True;
+                 xdr_load_kernel(&error);
+	}
+/*
+ * option pn specifies program number (to be used in conjunction with nodb)
+ */
+	prog_number = pn;
+/*
+ * unregister this program number from the portmapper - this is potentially
+ * dangerous because it can unregister another running server. we assume
+ * the -pn option is used by those who know what they are doing ...
+ */
+	if (prog_number != 0)
+	{
+		pmap_unset (prog_number, API_VERSION);
+		pmap_unset (prog_number, ASYNCH_API_VERSION);
+	}
+/*
+ * option -device means remaining command line arguments are device names
+ */
+	config_flags.device_no = n_device;
+	config_flags.device_list = device_list;
 
 #ifdef vxworks
 /*
@@ -520,14 +467,15 @@ int main (argc,argv)
         DevVarStringArray       default_access;
         db_resource             res_tab;
 
-        long    prog_number;
+        long    prog_number=0;
         long    status;
         long    error = 0;
         int     pid = 0;
         short   m_opt = False;
         short   s_opt = True;
+        short   nodb_opt = False;
         short   sig;
-        short   i;
+        short   i,j;
 
 	/*
 	 *  read device server's class name and personal name
@@ -537,7 +485,8 @@ int main (argc,argv)
 #ifndef _NT
 	if (argc < 2)
 	{
-	   printf ("usage :  %s personal_name {-m} {-s}\n",argv[0]);
+/*	   printf ("usage :  %s personal_name {-m} {-s} {-nodb} {-pn program #} {-device dev1 ...}\n",argv[0]);*/
+	   printf ("usage :  %s personal_name {-nodb} {-pn program #} {-device device1 ...}\n",argv[0]);
 	   exit (1);
 	}
 #else
@@ -547,6 +496,10 @@ int main (argc,argv)
 	}
 #endif  /* !_NT */
 
+/*
+ * make sure all config flags are set to zero before starting
+ */
+	memset(&config_flags, 0, sizeof(config_flags));
 #if defined (unix)
   	proc_name = (char *)strrchr (argv[0],'/');
 #endif	/*unix*/
@@ -594,15 +547,56 @@ int main (argc,argv)
 	 */
 
 	if (argc > 2)
-	   {
+	{
 	   for (i=2; i<(argc); i++)
-	      {
+	   {
 	      if (strcmp (argv[i],"-m") == 0)
 		 m_opt = True;
 	      if (strcmp (argv[i],"-s") == 0)
 		 s_opt = True;
+/*
+ * option -nodb means run device server without database
+ */
+	      if (strcmp (argv[i],"-nodb") == 0)
+	      {
+		 nodb_opt = True;
+		 config_flags.no_database = True;
+		 xdr_load_kernel(&error);
 	      }
+/*
+ * option -pn specifies program number (to be used in conjunction with -nodb)
+ */
+	      if (strcmp (argv[i],"-pn") == 0)
+	      {
+		 sscanf(argv[i+1],"%d",&prog_number);
+/*
+ * unregister this program number from the portmapper - this is potentially
+ * dangerous because it can unregister another running server. we assume
+ * the -pn option is used by those who know what they are doing ...
+ */
+		 if (prog_number != 0)
+		 {
+        	    pmap_unset (prog_number, API_VERSION);
+        	    pmap_unset (prog_number, ASYNCH_API_VERSION);
+		 }
+		 i++;
+              }
+/*
+ * option -device means remaining command line arguments are device names
+ */
+	      if (strcmp (argv[i],"-device") == 0)
+	      {
+		 config_flags.device_no = argc-i-1;
+		 config_flags.device_list = (char**)malloc(config_flags.device_no*sizeof(char));
+		 for (j=i+1; j<argc; j++)
+		 {
+		 	config_flags.device_list[j-i-1] = (char*)malloc(strlen(argv[j])+1);
+		 	sprintf(config_flags.device_list[j-i-1],"%s",argv[j]);
+		 }
+		 i = j;
+              }
 	   }
+	}
 	memset  (dsn_name,0,sizeof(dsn_name));
 	strncat (dsn_name , proc_name, 23);
 	strncat (dsn_name , "/", 1);
@@ -741,15 +735,17 @@ int main (argc,argv)
 #endif /* OSK || _OSK */
 
 
+	if (nodb_opt == False)
+	{
 /*
- *  import database server  
+ *  if database required then import database server  
  */
 
-	if ( db_import (&error) < 0 )
-	   {
-	   dev_printerror_no (SEND,"db_import failed",error);
-	   exit(-1);
-	   }		
+		if ( db_import (&error) < 0 )
+	   	{
+	   	dev_printerror_no (SEND,"db_import failed",error);
+	   	exit(-1);
+	   	}		
 
 
 /*
@@ -757,11 +753,11 @@ int main (argc,argv)
  *  is mapped to portmap or still running
  */
 
-	if ( svc_check(&error) < 0 )
-	   {
-	   dev_printerror_no (SEND,"svc_check()",error);
-	   exit(-1);
-	   }		
+		if ( svc_check(&error) < 0 )
+	   	{
+	   	dev_printerror_no (SEND,"svc_check()",error);
+	   	exit(-1);
+	   	}		
 
 
 /*
@@ -770,52 +766,53 @@ int main (argc,argv)
  * security database.
  */
 
-       if ( config_flags.security == True )
-	   {
-	   default_access.length   = 0;
-	   default_access.sequence = NULL;
+       		if ( config_flags.security == True )
+	   	{
+	   	default_access.length   = 0;
+	   	default_access.sequence = NULL;
 
-       	   sprintf (res_name, "default");
-	   res_tab.resource_name = res_name;
-	   res_tab.resource_type = D_VAR_STRINGARR;
-	   res_tab.resource_adr  = &default_access;
+       	   	sprintf (res_name, "default");
+	   	res_tab.resource_name = res_name;
+	   	res_tab.resource_type = D_VAR_STRINGARR;
+	   	res_tab.resource_adr  = &default_access;
 
-	   sprintf (res_path, "SEC/MINIMAL/ACC_RIGHT");
+	   	sprintf (res_path, "SEC/MINIMAL/ACC_RIGHT");
 
-	   if (db_getresource (res_path, &res_tab, 1, &error) == DS_NOTOK)
-	      {
-	      dev_printerror_no (SEND,
-	      "db_getresource() get default security access right\n",error);
-	      exit (-1);
-	      }
+	   	if (db_getresource (res_path, &res_tab, 1, &error) == DS_NOTOK)
+	      	{
+	      	dev_printerror_no (SEND,
+	      	"db_getresource() get default security access right\n",error);
+	      	exit (-1);
+	      	}
 
 /*
  * Transform the string array into an access right value.
  */
 
-           if ( default_access.length > 0 )
-	      {
-              for (i=0; i<SEC_LIST_LENGTH; i++)
-                 {
-                 if (strcmp (default_access.sequence[0], 
-			     DevSec_List[i].access_name) == 0)
-                    {
-                    minimal_access = DevSec_List[i].access_right;
-                    break;
-                    }
-                 }
-              if ( i == SEC_LIST_LENGTH )
-                 {
-                 minimal_access = NO_ACCESS;
-                 }
-	      }	 
-	   else 
-	      {
-              minimal_access = NO_ACCESS;
-	      }
+           	if ( default_access.length > 0 )
+	      	{
+              	for (i=0; i<SEC_LIST_LENGTH; i++)
+                 	{
+                 	if (strcmp (default_access.sequence[0], 
+			     	DevSec_List[i].access_name) == 0)
+                    	{
+                    	minimal_access = DevSec_List[i].access_right;
+                    	break;
+                    	}
+                 	}
+              		if ( i == SEC_LIST_LENGTH )
+                 	{
+                 	minimal_access = NO_ACCESS;
+                 	}
+	      	}	 
+	   	else 
+	      	{
+              	minimal_access = NO_ACCESS;
+	      	}
 
-	   free_var_str_array (&default_access);
-	   }
+	   	free_var_str_array (&default_access);
+	   	}
+	}		
 
 /*
  * let portmapper choose port numbers for services 
@@ -823,7 +820,7 @@ int main (argc,argv)
         udp_socket = RPC_ANYSOCK;
         tcp_socket = RPC_ANYSOCK;
 
-    /*
+    	/*
 	 *  create server handle and register to portmap
 	 */
 
@@ -851,7 +848,10 @@ int main (argc,argv)
 
 	for (i=0; i<3; i++)
 	{
-		prog_number = gettransient(dsn_name);
+		if (prog_number == 0)
+		{
+			prog_number = gettransient(dsn_name);
+		}
 		if( prog_number == 0 )
 		{
 	  		dev_printerror_no(SEND,"gettransient: no free programm nnumber\n",error);
@@ -1092,7 +1092,8 @@ int APIENTRY WinMain(
 
 	if(gArgc < 2) {
 		char msg[1024];
-		sprintf (msg,"usage :  %s personal_name [-m] [-s]\n",gszAppName);
+/*		sprintf (msg,"usage :  %s personal_name [-m] [-s]\n",gszAppName);*/
+		sprintf (msg,"usage :  %s personal_name [-nodb] [-pn number] [-device device1 ...]\n",gszAppName);
 		MessageBox((HWND)NULL, msg, TITLE_STR, MB_INFO);
 		return(FALSE);
 	}
