@@ -1,4 +1,4 @@
-static char RcsId[] = "@(#)$Header: asyn_api.c,v 8.30 2001/11/12 09:59:58 goetz Rel $";
+static char RcsId[] = "@(#)$Header: /segfs/dserver/system/api/apilib/src/RCS/asyn_api.c,v 8.48 2002/09/04 12:55:52 goetz Rel $";
 /*+*******************************************************************
 
  File       :	asyn_api.c
@@ -25,15 +25,69 @@ static char RcsId[] = "@(#)$Header: asyn_api.c,v 8.30 2001/11/12 09:59:58 goetz
 
  Original   :	January 1997
 
- $Revision: 8.30 $
- $Date: 2001/11/12 09:59:58 $
+ $Revision: 8.48 $
+ $Date: 2002/09/04 12:55:52 $
 
  $Author: goetz $
 
- $Log:	asyn_api.c,v $
- * Revision 8.30  2001/11/12  09:59:58  09:59:58  goetz (Andy Goetz)
- * updated C port for Windows 95/98/NT using Visual C++ 6
+ $Log: asyn_api.c,v $
+ Revision 8.48  2002/09/04 12:55:52  goetz
+ changed char* to string for tango api in tango_api.cpp
+
+ Revision 8.47  2002/06/27 11:56:58  goetz
+ fixed bug in stateless import with database
+
+ Revision 8.46  2002/06/25 07:26:28  goetz
+ extended stateless import to host down and all rpc errors
+
+ Revision 8.45  2002/06/18 07:44:01  goetz
+ NFILE reduced to 100 for OS9
+
+ Revision 8.44  2002/06/11 17:32:28  goetz
+ fixed double declaration of i in tango_api.cpp
+
+ Revision 8.43  2002/06/10 12:09:37  goetz
+ added Tango::INIT state to tango_api.cpp
+
+ Revision 8.42  2002/05/30 15:11:42  goetz
+ ported to C++ on Windows
+
+ Revision 8.41  2002/04/14 13:06:59  goetz
+ ported -nodb option to Windows
+
+ * Revision 8.40  2002/03/18  10:10:42  10:10:42  goetz (Andy Goetz)
+ * removed ^M from files which were confusing Ultra C++ compiler
  * 
+ * Revision 8.39  2002/03/18  05:48:50  05:48:50  goetz (Andy Goetz)
+ * added tango_dev_free() and dev_error_clear(); error message in command_handler
+ * 
+ Revision 8.38  2002/03/13 07:29:24  goetz
+ fixed bug initializing struct _devserver to zero; rpc_protocol=D_UDP
+
+ Revision 8.37  2002/03/11 14:20:18  goetz
+ initalise prog_number and config_flags to zero at startup
+
+ Revision 8.36  2002/03/07 15:58:44  goetz
+ fixed leak in extract_device_name
+
+ Revision 8.35  2002/03/06 22:08:42  goetz
+ made stateless import and reimport work for no database devices
+
+ Revision 8.34  2002/03/06 21:00:07  goetz
+ added -nodb option to device_server(); suppressed -m -s; improved dev_cmd_query
+
+ Revision 8.33  2002/03/05 11:52:47  goetz
+ added command name to C++ commands_list, asynchronous and events support -nodb
+
+ Revision 8.32  2002/03/03 22:44:50  goetz
+ added TACO-lite option i.e. no database
+
+ Revision 8.31  2002/02/28 12:13:05  goetz
+ setup_config() and setup_config_multi() now call rpc_nt_init() for Windows
+
+ Revision 8.30  2001/11/12 09:59:58  goetz
+ updated C port for Windows 95/98/NT using Visual C++ 6
+
  Revision 8.29  2001/07/26 05:05:07  goetz
  fixed error in CORBA::is_nil() test
 
@@ -182,9 +236,17 @@ static char RcsId[] = "@(#)$Header: asyn_api.c,v 8.30 2001/11/12 09:59:58 goetz
 #endif /* _UCC */
 
 
+#ifdef __cplusplus
+extern "C" configuration_flags config_flags;
+#else
 extern configuration_flags config_flags;
+#endif
 
+#ifdef __cplusplus
+extern "C" nethost_info *multi_nethost;
+#else
 extern nethost_info *multi_nethost;
+#endif
 
 extern server_connections svr_conns[];
 /*
@@ -206,8 +268,8 @@ extern int ds_rpc_svc_fd; /* global variable - client rpc file descriptor */
  * global variables indicating the sockets used by the synchronous and
  * asynchronous rpc services (used by dev_synch())
  */
-extern long synch_svc_udp_sock;
-extern long synch_svc_tcp_sock;
+long synch_svc_udp_sock;
+long synch_svc_tcp_sock;
 long asynch_svc_tcp_sock;
 
 /* 
@@ -313,8 +375,11 @@ long _DLLFunc dev_putget_asyn (devserver ds, long cmd,
  * save the device's nethost in an intermediate variable
  * to make it more accessible
  */
-	i_nethost = ds->i_nethost;
-	nethost = &multi_nethost[i_nethost];
+	if (!ds->no_database)
+	{
+		i_nethost = ds->i_nethost;
+		nethost = &multi_nethost[i_nethost];
+	}
 
 
 /*
@@ -341,11 +406,14 @@ long _DLLFunc dev_putget_asyn (devserver ds, long cmd,
  * verify the security key
  */
 
-	if ( nethost->config_flags.security == True )
+	if (!ds->no_database)
 	{
-		if ( verify_sec_key (ds, &client_id, error) == DS_NOTOK )
+		if ( nethost->config_flags.security == True )
 		{
-			return (DS_NOTOK);
+			if ( verify_sec_key (ds, &client_id, error) == DS_NOTOK )
+			{
+				return (DS_NOTOK);
+			}
 		}
 	}
 
@@ -600,8 +668,11 @@ long _DLLFunc dev_putget_raw_asyn (devserver ds, long cmd,
  * save the device's nethost in an intermediate variable
  * to make it more accessible
  */
-	i_nethost = ds->i_nethost;
-	nethost = &multi_nethost[i_nethost];
+	if (!ds->no_database)
+	{
+		i_nethost = ds->i_nethost;
+		nethost = &multi_nethost[i_nethost];
+	}
 
 
 /*
@@ -628,11 +699,14 @@ long _DLLFunc dev_putget_raw_asyn (devserver ds, long cmd,
  * verify the security key
  */
 
-	if ( nethost->config_flags.security == True )
+	if (!ds->no_database)
 	{
-		if ( verify_sec_key (ds, &client_id, error) == DS_NOTOK )
+		if ( nethost->config_flags.security == True )
 		{
-			return (DS_NOTOK);
+			if ( verify_sec_key (ds, &client_id, error) == DS_NOTOK )
+			{
+				return (DS_NOTOK);
+			}
 		}
 	}
 
