@@ -1,5 +1,5 @@
 static char RcsId[]         = 
-"@(#)$Header: ds_prog_vers3.c,v 8.40 2002/03/18 10:10:54 goetz Rel $";
+"@(#)$Header: /segfs/dserver/classes/main/src/RCS/ds_prog_vers3.c,v 8.48 2002/09/04 12:55:53 goetz Rel $";
 
 /*+*******************************************************************
 
@@ -15,11 +15,35 @@ static char RcsId[]         =
  Original   :	November 1994
 
 
- $Revision: 8.40 $
- $Date: 2002/03/18 10:10:54 $
+ $Revision: 8.48 $
+ $Date: 2002/09/04 12:55:53 $
  $Author: goetz $
 
- $Log:	ds_prog_vers3.c,v $
+ $Log: ds_prog_vers3.c,v $
+ Revision 8.48  2002/09/04 12:55:53  goetz
+ changed char* to string for tango api in tango_api.cpp
+
+ Revision 8.47  2002/06/27 11:57:00  goetz
+ fixed bug in stateless import with database
+
+ Revision 8.46  2002/06/25 07:26:29  goetz
+ extended stateless import to host down and all rpc errors
+
+ Revision 8.45  2002/06/18 07:44:02  goetz
+ NFILE reduced to 100 for OS9
+
+ Revision 8.44  2002/06/11 17:32:40  goetz
+ fixed double declaration of i in tango_api.cpp
+
+ Revision 8.43  2002/06/10 12:09:38  goetz
+ added Tango::INIT state to tango_api.cpp
+
+ Revision 8.42  2002/05/30 15:11:43  goetz
+ ported to C++ on Windows
+
+ Revision 8.41  2002/04/14 13:07:01  goetz
+ ported -nodb option to Windows
+
  * Revision 8.40  2002/03/18  10:10:54  10:10:54  goetz (Andy Goetz)
  * removed ^M from files which were confusing Ultra C++ compiler
  * 
