@@ -19,10 +19,10 @@
 
  $Author: beteva $
 
- $Log: DevCmds.h,v $
- Revision 4.37  2002/05/28 08:43:57  beteva
- Added Extended device commnads, removed some Hook commands
-
+ $Log:	DevCmds.h,v $
+ * Revision 4.37  2002/05/28  08:43:57  08:43:57  beteva (A.Beteva)
+ * Added Extended device commnads, removed some Hook commands
+ * 
  Revision 4.36  2002/03/07 20:52:43  goetz
  added cmd_name field to CmdListEntry
 
@@ -143,7 +143,7 @@
  */
 #ifdef _IDENT
 static char DevCmdsh[] = 
-"@(#)$Header: /segfs/dserver/system/api/cmds_err/include/RCS/DevCmds.h,v 4.37 2002/05/28 08:43:57 beteva Exp $";
+"@(#)$Header: DevCmds.h,v 4.37 2002/05/28 08:43:57 beteva Exp $";
 #endif /* _IDENT */
 
 
