@@ -1,6 +1,9 @@
-static char RcsId[] = "@(#)$Header: /segfs/dserver/system/dc/svc/RCS/dc_devinf.c,v 3.24 2002/03/12 11:26:55 goetz Rel $";
+static char RcsId[] = "@(#)$Header: /segfs/dserver/system/dc/svc/RCS/dc_devinf.c,v 3.25 2002/07/05 11:17:05 taurel Rel $";
 
 /* $Log: dc_devinf.c,v $
+ * Revision 3.25  2002/07/05 11:17:05  taurel
+ * DC servers now create their own devices and have default resource values
+ *
  * Revision 3.24  2002/03/12 11:26:55  goetz
  * solaris now uses sigset() and not sigvec anymore
  *
