@@ -1,6 +1,24 @@
-static char RcsId[] = "@(#)$Header: dcrd_svc.c,v 3.19 99/07/05 14:24:25 taurel Rel $";
+static char RcsId[] = "@(#)$Header: /segfs/dserver/system/dc/svc/RCS/dcrd_svc.c,v 3.25 2002/07/05 11:17:05 taurel Rel $";
 
-/* $Log:	dcrd_svc.c,v $
+/* $Log: dcrd_svc.c,v $
+ * Revision 3.25  2002/07/05 11:17:05  taurel
+ * DC servers now create their own devices and have default resource values
+ *
+ * Revision 3.24  2002/03/12 11:26:55  goetz
+ * solaris now uses sigset() and not sigvec anymore
+ *
+ * Revision 3.23  1901/02/20 17:47:21  taurel
+ * Add some test on the ptr retrieved from shared memory for the read server (dc_read.c file)
+ *
+ * Revision 3.22  2001/02/19 12:50:14  goetz
+ * checkin for taurel
+ *
+ * Revision 3.21  2000/12/03 07:19:13  goetz
+ * ported to Linux
+ *
+ * Revision 3.20  2000/03/13 15:28:33  taurel
+ * Adapted to the new release of gettranscient (DSAIPI release 7.8 and above)
+ *
  * Revision 3.19  99/07/05  14:24:25  14:24:25  taurel (E.Taurel)
  * Porte dto new release of gettranscienr_ut. I don't understand how it worked
  * before !!
@@ -159,18 +177,17 @@ extern xresh *ptr_xresh;
 
 /* Signal handler for all the signals which kill the process */
 
-void un_register_prog(signo)
-int signo;
+void un_register_prog(int signo)
 {
 	long error;
-
+	
 	pmap_unset(pgnum, DC_VERS);
 
 /* Added code to unregister the server from static db */
 
 	db_svc_unreg(ds_name,&error);
 
-	exit(1);
+	exit(-1);
 }
 
 /* Signal handler for the alarm signal (time-out on asemaphore) */
@@ -234,10 +251,13 @@ char *argv[];
 	struct sockaddr_in so;
 	char hostna[32];
 	char full_name[80];
-#ifdef sun
+#ifdef OBSOLETE_SUN
 	int sig_mask;
 	struct sigvec sighand;
 #endif
+#ifdef linux
+	struct sigaction sigact;
+#endif /* linux */
 
 /* Added variables to manage transient program number */
 
@@ -265,7 +285,7 @@ char *argv[];
 
 /* Install signal handler */
 
-#ifdef sun
+#ifdef OBSOLETE_SUN
 	sig_mask = sigmask(SIGHUP);
 	sigsetmask(sig_mask);
 
@@ -292,6 +312,7 @@ char *argv[];
 	sigvec(SIGXCPU,&sighand,NULL);
 	sigvec(SIGXFSZ,&sighand,NULL);
 #else
+#ifndef linux
 	(void) sigignore(SIGHUP);
 	(void) sigset(SIGINT, un_register_prog);
 	(void) sigset(SIGQUIT, un_register_prog);
@@ -302,8 +323,34 @@ char *argv[];
 	(void) sigset(SIGUSR2, default_sig);
 	(void) sigset(SIGVTALRM, default_sig);
 	(void) sigset(SIGPROF, default_sig);
+#ifndef _solaris
 	(void) sigset(SIGLOST, default_sig);
-#endif /* sun */
+#endif /* _solaris */
+#else
+	sigact.sa_flags = 0;
+	sigemptyset(&sigact.sa_mask);
+	sigact.sa_handler = SIG_IGN;
+	sigaction(SIGHUP, &sigact, NULL);
+	sigact.sa_handler = un_register_prog;
+	sigaction(SIGINT, &sigact, NULL);
+	sigact.sa_handler = un_register_prog;
+	sigaction(SIGQUIT, &sigact, NULL);
+	sigact.sa_handler = un_register_prog;
+	sigaction(SIGTERM, &sigact, NULL);
+	sigact.sa_handler = time_out_prog;
+	sigaction(SIGALRM, &sigact, NULL);
+	sigact.sa_handler = default_sig;
+	sigaction(SIGPIPE, &sigact, NULL);
+	sigact.sa_handler = default_sig;
+	sigaction(SIGUSR1, &sigact, NULL);
+	sigact.sa_handler = default_sig;
+	sigaction(SIGUSR2, &sigact, NULL);
+	sigact.sa_handler = default_sig;
+	sigaction(SIGVTALRM, &sigact, NULL);
+	sigact.sa_handler = default_sig;
+	sigaction(SIGPROF, &sigact, NULL);
+#endif /* !linux */
+#endif /* OBSOLETE_SUN */
 
 /* Change max number of open files to 120 */
 
@@ -328,7 +375,7 @@ char *argv[];
 	strcat(full_name,"/");
 	strcat(full_name,argv[1]);
 	
-	pgnum = gettransient_ut(full_name,&sock_udp,&sock_tcp);
+	pgnum = gettransient(full_name);
 
 	if (pgnum == 0)
 	{
@@ -341,11 +388,6 @@ char *argv[];
 	printf("Program number : %x in hexa or %d in decimal\n",pgnum,pgnum);
 #endif /* DEBUG */
 
-#ifdef _solaris
-	close(sock_tcp);
-	sock_tcp = RPC_ANYSOCK;
-	pmap_unset(pgnum,DC_VERS);
-#endif /* _solaris */
 
 	transp_tcp = svctcp_create(sock_tcp,0,0);
 
@@ -363,11 +405,6 @@ char *argv[];
 		leave(NO_UNREG);
 	}
 
-#ifdef _solaris
-	close(sock_udp);
-	sock_udp = RPC_ANYSOCK;
-#endif /* _solaris */
-
 	transp_udp = svcudp_create(sock_udp);
 	if (transp_udp == NULL)
 	{
@@ -499,7 +536,7 @@ dc_prog_1(rqstp, transp)
 	switch (rqstp->rq_proc)
 	{
 	case NULLPROC:
-		svc_sendreply(transp, xdr_void, NULL);
+		svc_sendreply(transp, (const xdrproc_t)xdr_void, NULL);
 		return;
 
 	case DC_DEVGET:
@@ -534,11 +571,11 @@ dc_prog_1(rqstp, transp)
 
 	case RPC_CHECK:
 		tmp_ch = ds_name;
-		svc_sendreply(transp,xdr_wrapstring,(caddr_t)&tmp_ch);
+		svc_sendreply(transp,(const xdrproc_t)xdr_wrapstring,(caddr_t)&tmp_ch);
 		return;
 		
 	case RPC_QUIT_SERVER:
-		svc_sendreply(transp,xdr_void,NULL);
+		svc_sendreply(transp,(const xdrproc_t)xdr_void,NULL);
 		pid = getpid();
 		kill(pid,SIGQUIT);
 		return;
@@ -550,17 +587,17 @@ dc_prog_1(rqstp, transp)
 
 	memset(&argument, 0, sizeof(argument));
 
-	if (!svc_getargs(transp, xdr_argument, (caddr_t)&argument))
+	if (!svc_getargs(transp, (const xdrproc_t)xdr_argument, (caddr_t)&argument))
 	{
 		svcerr_decode(transp);
 		return;
 	}
 	result = (*local)(&argument, rqstp);
-	if (result != NULL && !svc_sendreply(transp, xdr_result, result))
+	if (result != NULL && !svc_sendreply(transp, (const xdrproc_t)xdr_result, result))
 	{
 		svcerr_systemerr(transp);
 	}
-	if (!svc_freeargs(transp, xdr_argument, (caddr_t)&argument))
+	if (!svc_freeargs(transp, (const xdrproc_t)xdr_argument, (caddr_t)&argument))
 	{
 		fprintf(stderr, "unable to free arguments\n");
 		exit(1);
@@ -712,6 +749,9 @@ char *c_proc_name;
 	char h_name[40];
 	char proc_name[40];
 	char *ptr;
+	char dev_def[256];
+	char **dev_def_array;
+	long dev_def_err;
 
 /* Get host information */
 
@@ -764,7 +804,7 @@ char *c_proc_name;
 		fprintf(stderr,"dc_server_rd : Error code : %d\n",error);
 		return(-1);
 	}
-
+	
 /* Build real process name */
 
 	ptr = strrchr(c_proc_name,'/');
@@ -790,13 +830,50 @@ char *c_proc_name;
 
 	if (db_dev_export(&devinfo,1,&error))
 	{
-		fprintf(stderr,"dc_server_rd : Can't export me to outside world, exiting...\n");
-		fprintf(stderr,"dc_server_rd : Error code : %d\n",error);
-		return(-1);
+		if (error != DbErr_DeviceNotDefined)
+		{
+			fprintf(stderr,"dc_server_rd : Can't export me to outside world, exiting...\n");
+			fprintf(stderr,"dc_server_rd : Error code : %d\n",error);
+			return(-1);
+		}
+		else
+		{
+		
+/* Build the device definition string */
+
+			strcpy(dev_def,ds_name);
+			strcat(dev_def,"/device:");
+			strcat(dev_def,d_name);
+
+			dev_def_array = calloc(1,sizeof(char *));
+			dev_def_array[0] = dev_def;
+		
+			if (db_upddev(1,dev_def_array,&dev_def_err,&error) == -1)
+			{
+				fprintf(stderr,"dc_server_rd: Pseudo device for dc server not defined in db\n");
+				fprintf(stderr," and I can't defined it. Error = %d\n",error);
+				return(-1);
+			}
+
+/* Export me to the outside world */
+			
+			if (db_dev_export(&devinfo,1,&error) == -1)
+			{
+				fprintf(stderr,"dc_server_rd : Can't export me to outside world, exiting...\n");
+				fprintf(stderr,"dc_server_rd : Error code : %d\n",error);
+				return(-1);
+			}
+		}
 	}
 
-/* Retrieve server resources */
+/* Retrieve server resources. Assign some default values to these resources in
+   case they are not defined in database */
 
+	shift_dt = 2;
+	req.start_req = 8;
+	req.start_nb = 8;
+	req.update = 256;
+	
 	res_serv_get[0].resource_adr = &req.start_req;
 	res_serv_get[1].resource_adr = &req.start_nb;
 	res_serv_get[2].resource_adr = &req.update;
