@@ -1,5 +1,5 @@
 static char RcsId[] =
-"@(#)$Header: ManagerMain.c,v 4.12 20/0./3. 5.:7.:3. taurel Rel $ ";
+"@(#)$Header: /segfs/dserver/system/manager/src/RCS/ManagerMain.c,v 4.13 2002/05/28 13:42:34 goetz Exp $ ";
 /********************************************************************
 
  File:          ManagerMain.c
@@ -15,15 +15,19 @@ static char RcsId[] =
  Original: 	January 1991
 
 
- $Revision: 4.12 $
- $Date: 20/0./3. 5.:7.:3. $
+ $Revision: 4.13 $
+ $Date: 2002/05/28 13:42:34 $
 
- $Author: taurel $
+ $Author: goetz $
+
+ $Log: ManagerMain.c,v $
+ Revision 4.13  2002/05/28 13:42:34  goetz
+ replaced DSHOME by TACO_PATH, exec() of database/manager now take PATH into
+ account
+
+ Revision 4.12  2000/03/15 17:23:22  taurel
+ Remove the chmod for unix operating system
 
- $Log:	ManagerMain.c,v $
- * Revision 4.12  20/0./3.  5.:7.:3.  5.:7.:3.  taurel (E.Taurel)
- * Remove the chmod for unix operating system
- * 
  * Revision 4.11  99/11/21  20:36:15  20:36:15  goetz (Andy Goetz)
  * calling svc_destroy() before execv() for database and message server (M.Diehl patch)
  * 
@@ -177,16 +181,17 @@ main (argc,argv)
 	 */
 
 #ifdef unix
-	if ( (dshome = (char *)getenv ("DSHOME")) == NULL )
+	if ( (dshome = (char *)getenv ("TACO_PATH")) == NULL )
 	   {
-	   printf ("Environment variable DSHOME not defined, exiting...\n");
-	   exit (-1);
+	   printf ("Environment variable TACO_PATH not defined, assume database and message server are in path...\n");
 	   }
 
+/*
 	if ( (display = (char *)getenv ("DISPLAY")) == NULL )
 	   {
 	   display = "localhost:0.0";
 	   }
+ */
 
         if ( (dbhost = (char *)getenv ("DBHOST")) == NULL )
            {
@@ -202,6 +207,15 @@ main (argc,argv)
 	dshome = "/h0";
 #endif /* _OSK */
 
+	if (dshome != NULL)
+	{
+		sprintf (homepath, "%s", dshome);
+	}
+	else
+	{
+		sprintf(homepath, "./");
+	}
+#ifdef NEVER
 #ifdef linuxx86
 	sprintf (homepath, "%s/system/bin/linux/x86", dshome);
 #endif /* linuxx86 */
@@ -220,6 +234,7 @@ main (argc,argv)
 #ifdef hpux10
 	sprintf (homepath, "%s/system/bin/hpux10.2", dshome);
 #endif /* hpux10 */
+#endif /* NEVER */
 
 #ifdef unix
 	if ( (fptr = fopen (homepath,"r")) == NULL )
@@ -228,7 +243,7 @@ main (argc,argv)
 	if ( (fptr = fopen (homepath,"d")) == NULL )
 #endif /* _OSK */
 	   {
-	   printf ("DSHOME leads to a strange directory, exiting...\n");
+	   printf ("TACO_PATH leads to a strange directory, exiting...\n");
 	   exit (-1);
 	   }
 	else
@@ -516,7 +531,14 @@ main (argc,argv)
 	      else
 		 {
 		 /* Set path to DBM server */
-                 sprintf (homedir, "%s/%s", homepath, dbm_server);
+		 if (dshome != NULL)
+		 {
+                 	sprintf (homedir, "%s/%s", homepath, dbm_server);
+		 }
+		 else
+		 {
+                 	sprintf (homedir, "%s", dbm_server);
+		 }
 
 		 /* Set arguments for execv */
                  i = 0;
@@ -528,9 +550,9 @@ main (argc,argv)
 
 	      svc_destroy(transp); 
 	      
-              execv (homedir, cmd_argv);
+              execvp (homedir, cmd_argv);
 
-              fprintf (stderr,"execv failed, database_server not started\n");
+              fprintf (stderr,"execvp failed, database_server not started\n");
               fprintf (system_log,
 		       "execv failed, database_server not started\n");
               kill (pid,SIGQUIT);
@@ -552,7 +574,14 @@ main (argc,argv)
 
 	if (!msg_pid)
 	   {
-	   sprintf (homedir, "%s/MessageServer", homepath);
+	   if (dshome != NULL)
+	   {
+	     sprintf (homedir, "%s/MessageServer", homepath);
+	   }
+	   else
+	   {
+	     sprintf (homedir, "MessageServer", homepath);
+	   }
 	   i = 0;
 	   cmd_argv[i] = "MessageServer"; i++;
 	   cmd_argv[i] = nethost; i++;
@@ -560,9 +589,9 @@ main (argc,argv)
 
 	   svc_destroy(transp); 
 
-	   execv (homedir,cmd_argv);
+	   execvp (homedir,cmd_argv);
 
-      	   fprintf (stderr,"execv failed, message server not started\n");
+      	   fprintf (stderr,"execvp failed, message server not started\n");
       	   fprintf (system_log,"execv failed, message server not started\n");
  	   kill (pid,SIGQUIT);
 	   }
