@@ -1,7 +1,16 @@
-static char RcsId[] = "$Header: db_fillup.cpp,v 6.5 99/07/06 08:53:04 taurel Exp $";
+static char RcsId[] = "$Header: db_fillup.cpp,v 6.8 2002/09/03 13:40:54 taurel Rel $";
 
 /* $Log:	db_fillup.cpp,v $
-Revision 6.5  99/07/06  08:53:04  08:53:04  taurel (Emmanuel Taurel)
+Revision 6.8  2002/09/03  13:40:54  13:40:54  taurel (E.Taurel)
+db_devinfo now print all available info even for unexported device
+
+ * Revision 6.7  2002/09/03 11:24:20  goetz
+ * fixed db_fillup to follow directory links
+ *
+ * Revision 6.6  2002/03/12 11:29:56  goetz
+ * added sun to ifdef linux for flags = O_CREAT | O_RDWR; in db_fillup 0 case
+ *
+Revision 6.5  99/07/06  08:53:04  08:53:04  taurel (E.Taurel)
 Remove all access inside the dbm structure (no pagf anymore)
 
 Revision 6.4  99/06/16  13:24:52  13:24:52  taurel (Emmanuel Taurel)
@@ -249,7 +258,7 @@ static void from_res()
 
 /* Get the contents of this directory */
 
-	if (system("ls -R1p >/usr/tmp/l"))
+	if (system("ls -R1pL >/usr/tmp/l"))
 	{
 		fprintf(stderr,"db_fillup : Can't get contents of directory \n");
 		leave();
@@ -1404,7 +1413,7 @@ static void create_db()
 
 /* Create database tables of the database definition */
 
-#ifdef linux
+#if defined linux || sun
 	flags = O_CREAT | O_RDWR;
 #else
 	flags = O_CREAT;
